/****************************************************************************
** Meta object code from reading C++ file 'scripting.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libksysguard-5.8.9/processui/scripting.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scripting.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Scripting_t {
    QByteArrayData data[8];
    char stringdata0[92];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Scripting_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Scripting_t qt_meta_stringdata_Scripting = {
    {
QT_MOC_LITERAL(0, 0, 9), // "Scripting"
QT_MOC_LITERAL(1, 10, 14), // "stopAllScripts"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 13), // "runScriptSlot"
QT_MOC_LITERAL(4, 40, 22), // "setupJavascriptObjects"
QT_MOC_LITERAL(5, 63, 13), // "refreshScript"
QT_MOC_LITERAL(6, 77, 6), // "zoomIn"
QT_MOC_LITERAL(7, 84, 7) // "zoomOut"

    },
    "Scripting\0stopAllScripts\0\0runScriptSlot\0"
    "setupJavascriptObjects\0refreshScript\0"
    "zoomIn\0zoomOut"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Scripting[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x0a /* Public */,
       3,    0,   45,    2, 0x08 /* Private */,
       4,    0,   46,    2, 0x08 /* Private */,
       5,    0,   47,    2, 0x08 /* Private */,
       6,    0,   48,    2, 0x08 /* Private */,
       7,    0,   49,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Scripting::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Scripting *_t = static_cast<Scripting *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->stopAllScripts(); break;
        case 1: _t->runScriptSlot(); break;
        case 2: _t->setupJavascriptObjects(); break;
        case 3: _t->refreshScript(); break;
        case 4: _t->zoomIn(); break;
        case 5: _t->zoomOut(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject Scripting::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Scripting.data,
      qt_meta_data_Scripting,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Scripting::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Scripting::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Scripting.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Scripting::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
struct qt_meta_stringdata_ProcessObject_t {
    QByteArrayData data[54];
    char stringdata0[615];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ProcessObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ProcessObject_t qt_meta_stringdata_ProcessObject = {
    {
QT_MOC_LITERAL(0, 0, 13), // "ProcessObject"
QT_MOC_LITERAL(1, 14, 10), // "fileExists"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 8), // "filename"
QT_MOC_LITERAL(4, 35, 8), // "readFile"
QT_MOC_LITERAL(5, 44, 3), // "pid"
QT_MOC_LITERAL(6, 48, 4), // "ppid"
QT_MOC_LITERAL(7, 53, 4), // "name"
QT_MOC_LITERAL(8, 58, 8), // "fullname"
QT_MOC_LITERAL(9, 67, 3), // "rss"
QT_MOC_LITERAL(10, 71, 4), // "urss"
QT_MOC_LITERAL(11, 76, 10), // "numThreads"
QT_MOC_LITERAL(12, 87, 5), // "fsgid"
QT_MOC_LITERAL(13, 93, 9), // "parentPid"
QT_MOC_LITERAL(14, 103, 5), // "login"
QT_MOC_LITERAL(15, 109, 3), // "uid"
QT_MOC_LITERAL(16, 113, 4), // "euid"
QT_MOC_LITERAL(17, 118, 4), // "suid"
QT_MOC_LITERAL(18, 123, 5), // "fsuid"
QT_MOC_LITERAL(19, 129, 3), // "gid"
QT_MOC_LITERAL(20, 133, 4), // "egid"
QT_MOC_LITERAL(21, 138, 4), // "sgid"
QT_MOC_LITERAL(22, 143, 9), // "tracerpid"
QT_MOC_LITERAL(23, 153, 3), // "tty"
QT_MOC_LITERAL(24, 157, 8), // "userTime"
QT_MOC_LITERAL(25, 166, 7), // "sysTime"
QT_MOC_LITERAL(26, 174, 9), // "userUsage"
QT_MOC_LITERAL(27, 184, 8), // "sysUsage"
QT_MOC_LITERAL(28, 193, 14), // "totalUserUsage"
QT_MOC_LITERAL(29, 208, 13), // "totalSysUsage"
QT_MOC_LITERAL(30, 222, 11), // "numChildren"
QT_MOC_LITERAL(31, 234, 9), // "niceLevel"
QT_MOC_LITERAL(32, 244, 9), // "scheduler"
QT_MOC_LITERAL(33, 254, 15), // "ioPriorityClass"
QT_MOC_LITERAL(34, 270, 11), // "ioniceLevel"
QT_MOC_LITERAL(35, 282, 6), // "vmSize"
QT_MOC_LITERAL(36, 289, 5), // "vmRSS"
QT_MOC_LITERAL(37, 295, 6), // "vmURSS"
QT_MOC_LITERAL(38, 302, 11), // "pixmapBytes"
QT_MOC_LITERAL(39, 314, 19), // "hasManagedGuiWindow"
QT_MOC_LITERAL(40, 334, 7), // "command"
QT_MOC_LITERAL(41, 342, 6), // "status"
QT_MOC_LITERAL(42, 349, 16), // "ioCharactersRead"
QT_MOC_LITERAL(43, 366, 19), // "ioCharactersWritten"
QT_MOC_LITERAL(44, 386, 14), // "ioReadSyscalls"
QT_MOC_LITERAL(45, 401, 15), // "ioWriteSyscalls"
QT_MOC_LITERAL(46, 417, 24), // "ioCharactersActuallyRead"
QT_MOC_LITERAL(47, 442, 27), // "ioCharactersActuallyWritten"
QT_MOC_LITERAL(48, 470, 20), // "ioCharactersReadRate"
QT_MOC_LITERAL(49, 491, 23), // "ioCharactersWrittenRate"
QT_MOC_LITERAL(50, 515, 18), // "ioReadSyscallsRate"
QT_MOC_LITERAL(51, 534, 19), // "ioWriteSyscallsRate"
QT_MOC_LITERAL(52, 554, 28), // "ioCharactersActuallyReadRate"
QT_MOC_LITERAL(53, 583, 31) // "ioCharactersActuallyWrittenRate"

    },
    "ProcessObject\0fileExists\0\0filename\0"
    "readFile\0pid\0ppid\0name\0fullname\0rss\0"
    "urss\0numThreads\0fsgid\0parentPid\0login\0"
    "uid\0euid\0suid\0fsuid\0gid\0egid\0sgid\0"
    "tracerpid\0tty\0userTime\0sysTime\0userUsage\0"
    "sysUsage\0totalUserUsage\0totalSysUsage\0"
    "numChildren\0niceLevel\0scheduler\0"
    "ioPriorityClass\0ioniceLevel\0vmSize\0"
    "vmRSS\0vmURSS\0pixmapBytes\0hasManagedGuiWindow\0"
    "command\0status\0ioCharactersRead\0"
    "ioCharactersWritten\0ioReadSyscalls\0"
    "ioWriteSyscalls\0ioCharactersActuallyRead\0"
    "ioCharactersActuallyWritten\0"
    "ioCharactersReadRate\0ioCharactersWrittenRate\0"
    "ioReadSyscallsRate\0ioWriteSyscallsRate\0"
    "ioCharactersActuallyReadRate\0"
    "ioCharactersActuallyWrittenRate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ProcessObject[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
      49,   30, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x0a /* Public */,
       4,    1,   27,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool, QMetaType::QString,    3,
    QMetaType::QString, QMetaType::QString,    3,

 // properties: name, type, flags
       5, QMetaType::LongLong, 0x00095103,
       6, QMetaType::LongLong, 0x00095001,
       7, QMetaType::QString, 0x00095001,
       8, QMetaType::QString, 0x00095001,
       9, QMetaType::LongLong, 0x00095001,
      10, QMetaType::LongLong, 0x00095001,
      11, QMetaType::Int, 0x00095001,
      12, QMetaType::LongLong, 0x00095001,
      13, QMetaType::LongLong, 0x00095001,
      14, QMetaType::QString, 0x00095001,
      15, QMetaType::LongLong, 0x00095001,
      16, QMetaType::LongLong, 0x00095001,
      17, QMetaType::LongLong, 0x00095001,
      18, QMetaType::LongLong, 0x00095001,
      19, QMetaType::LongLong, 0x00095001,
      20, QMetaType::LongLong, 0x00095001,
      21, QMetaType::LongLong, 0x00095001,
      22, QMetaType::LongLong, 0x00095001,
      23, QMetaType::QByteArray, 0x00095001,
      24, QMetaType::LongLong, 0x00095001,
      25, QMetaType::LongLong, 0x00095001,
      26, QMetaType::Int, 0x00095001,
      27, QMetaType::Int, 0x00095001,
      28, QMetaType::Int, 0x00095001,
      29, QMetaType::Int, 0x00095001,
      30, QMetaType::Int, 0x00095001,
      31, QMetaType::Int, 0x00095001,
      32, QMetaType::Int, 0x00095001,
      33, QMetaType::Int, 0x00095001,
      34, QMetaType::Int, 0x00095001,
      35, QMetaType::LongLong, 0x00095001,
      36, QMetaType::LongLong, 0x00095001,
      37, QMetaType::LongLong, 0x00095001,
      38, QMetaType::LongLong, 0x00095001,
      39, QMetaType::Bool, 0x00095001,
      40, QMetaType::QString, 0x00095001,
      41, QMetaType::LongLong, 0x00095001,
      42, QMetaType::LongLong, 0x00095001,
      43, QMetaType::LongLong, 0x00095001,
      44, QMetaType::LongLong, 0x00095001,
      45, QMetaType::LongLong, 0x00095001,
      46, QMetaType::LongLong, 0x00095001,
      47, QMetaType::LongLong, 0x00095001,
      48, QMetaType::LongLong, 0x00095001,
      49, QMetaType::LongLong, 0x00095001,
      50, QMetaType::LongLong, 0x00095001,
      51, QMetaType::LongLong, 0x00095001,
      52, QMetaType::LongLong, 0x00095001,
      53, QMetaType::LongLong, 0x00095001,

       0        // eod
};

void ProcessObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ProcessObject *_t = static_cast<ProcessObject *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->fileExists((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->readFile((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        ProcessObject *_t = static_cast<ProcessObject *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qlonglong*>(_v) = _t->pid(); break;
        case 1: *reinterpret_cast< qlonglong*>(_v) = _t->parentPid(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->fullname(); break;
        case 4: *reinterpret_cast< qlonglong*>(_v) = _t->vmRSS(); break;
        case 5: *reinterpret_cast< qlonglong*>(_v) = _t->vmURSS(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->numThreads(); break;
        case 7: *reinterpret_cast< qlonglong*>(_v) = _t->fsgid(); break;
        case 8: *reinterpret_cast< qlonglong*>(_v) = _t->parentPid(); break;
        case 9: *reinterpret_cast< QString*>(_v) = _t->login(); break;
        case 10: *reinterpret_cast< qlonglong*>(_v) = _t->uid(); break;
        case 11: *reinterpret_cast< qlonglong*>(_v) = _t->euid(); break;
        case 12: *reinterpret_cast< qlonglong*>(_v) = _t->suid(); break;
        case 13: *reinterpret_cast< qlonglong*>(_v) = _t->fsuid(); break;
        case 14: *reinterpret_cast< qlonglong*>(_v) = _t->gid(); break;
        case 15: *reinterpret_cast< qlonglong*>(_v) = _t->egid(); break;
        case 16: *reinterpret_cast< qlonglong*>(_v) = _t->sgid(); break;
        case 17: *reinterpret_cast< qlonglong*>(_v) = _t->tracerpid(); break;
        case 18: *reinterpret_cast< QByteArray*>(_v) = _t->tty(); break;
        case 19: *reinterpret_cast< qlonglong*>(_v) = _t->userTime(); break;
        case 20: *reinterpret_cast< qlonglong*>(_v) = _t->sysTime(); break;
        case 21: *reinterpret_cast< int*>(_v) = _t->userUsage(); break;
        case 22: *reinterpret_cast< int*>(_v) = _t->sysUsage(); break;
        case 23: *reinterpret_cast< int*>(_v) = _t->totalUserUsage(); break;
        case 24: *reinterpret_cast< int*>(_v) = _t->totalSysUsage(); break;
        case 25: *reinterpret_cast< int*>(_v) = _t->numChildren(); break;
        case 26: *reinterpret_cast< int*>(_v) = _t->niceLevel(); break;
        case 27: *reinterpret_cast< int*>(_v) = _t->scheduler(); break;
        case 28: *reinterpret_cast< int*>(_v) = _t->ioPriorityClass(); break;
        case 29: *reinterpret_cast< int*>(_v) = _t->ioniceLevel(); break;
        case 30: *reinterpret_cast< qlonglong*>(_v) = _t->vmSize(); break;
        case 31: *reinterpret_cast< qlonglong*>(_v) = _t->vmRSS(); break;
        case 32: *reinterpret_cast< qlonglong*>(_v) = _t->vmURSS(); break;
        case 33: *reinterpret_cast< qlonglong*>(_v) = _t->pixmapBytes(); break;
        case 34: *reinterpret_cast< bool*>(_v) = _t->hasManagedGuiWindow(); break;
        case 35: *reinterpret_cast< QString*>(_v) = _t->command(); break;
        case 36: *reinterpret_cast< qlonglong*>(_v) = _t->status(); break;
        case 37: *reinterpret_cast< qlonglong*>(_v) = _t->ioCharactersRead(); break;
        case 38: *reinterpret_cast< qlonglong*>(_v) = _t->ioCharactersWritten(); break;
        case 39: *reinterpret_cast< qlonglong*>(_v) = _t->ioReadSyscalls(); break;
        case 40: *reinterpret_cast< qlonglong*>(_v) = _t->ioWriteSyscalls(); break;
        case 41: *reinterpret_cast< qlonglong*>(_v) = _t->ioCharactersActuallyRead(); break;
        case 42: *reinterpret_cast< qlonglong*>(_v) = _t->ioCharactersActuallyWritten(); break;
        case 43: *reinterpret_cast< qlonglong*>(_v) = _t->ioCharactersReadRate(); break;
        case 44: *reinterpret_cast< qlonglong*>(_v) = _t->ioCharactersWrittenRate(); break;
        case 45: *reinterpret_cast< qlonglong*>(_v) = _t->ioReadSyscallsRate(); break;
        case 46: *reinterpret_cast< qlonglong*>(_v) = _t->ioWriteSyscallsRate(); break;
        case 47: *reinterpret_cast< qlonglong*>(_v) = _t->ioCharactersActuallyReadRate(); break;
        case 48: *reinterpret_cast< qlonglong*>(_v) = _t->ioCharactersActuallyWrittenRate(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        ProcessObject *_t = static_cast<ProcessObject *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPid(*reinterpret_cast< qlonglong*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject ProcessObject::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ProcessObject.data,
      qt_meta_data_ProcessObject,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ProcessObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProcessObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ProcessObject.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ProcessObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 49;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 49;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 49;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 49;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 49;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 49;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
