/****************************************************************************
** Meta object code from reading C++ file 'ksysguardprocesslist.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libksysguard-5.8.9/processui/ksysguardprocesslist.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksysguardprocesslist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KSysGuardProcessList_t {
    QByteArrayData data[56];
    char stringdata0[806];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KSysGuardProcessList_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KSysGuardProcessList_t qt_meta_stringdata_KSysGuardProcessList = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KSysGuardProcessList"
QT_MOC_LITERAL(1, 21, 7), // "updated"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 18), // "processListChanged"
QT_MOC_LITERAL(4, 49, 16), // "selectionChanged"
QT_MOC_LITERAL(5, 66, 21), // "killSelectedProcesses"
QT_MOC_LITERAL(6, 88, 29), // "sendSignalToSelectedProcesses"
QT_MOC_LITERAL(7, 118, 3), // "sig"
QT_MOC_LITERAL(8, 122, 7), // "confirm"
QT_MOC_LITERAL(9, 130, 13), // "killProcesses"
QT_MOC_LITERAL(10, 144, 16), // "QList<long long>"
QT_MOC_LITERAL(11, 161, 4), // "pids"
QT_MOC_LITERAL(12, 166, 23), // "reniceSelectedProcesses"
QT_MOC_LITERAL(13, 190, 18), // "changeCpuScheduler"
QT_MOC_LITERAL(14, 209, 29), // "KSysGuard::Process::Scheduler"
QT_MOC_LITERAL(15, 239, 11), // "newCpuSched"
QT_MOC_LITERAL(16, 251, 19), // "newCpuSchedPriority"
QT_MOC_LITERAL(17, 271, 17), // "changeIoScheduler"
QT_MOC_LITERAL(18, 289, 35), // "KSysGuard::Process::IoPriorit..."
QT_MOC_LITERAL(19, 325, 10), // "newIoSched"
QT_MOC_LITERAL(20, 336, 18), // "newIoSchedPriority"
QT_MOC_LITERAL(21, 355, 15), // "reniceProcesses"
QT_MOC_LITERAL(22, 371, 9), // "niceValue"
QT_MOC_LITERAL(23, 381, 10), // "updateList"
QT_MOC_LITERAL(24, 392, 8), // "setState"
QT_MOC_LITERAL(25, 401, 20), // "ProcessFilter::State"
QT_MOC_LITERAL(26, 422, 5), // "state"
QT_MOC_LITERAL(27, 428, 22), // "setUpdateIntervalMSecs"
QT_MOC_LITERAL(28, 451, 13), // "intervalMSecs"
QT_MOC_LITERAL(29, 465, 13), // "setShowTotals"
QT_MOC_LITERAL(30, 479, 10), // "showTotals"
QT_MOC_LITERAL(31, 490, 22), // "selectAndJumpToProcess"
QT_MOC_LITERAL(32, 513, 3), // "pid"
QT_MOC_LITERAL(33, 517, 8), // "setUnits"
QT_MOC_LITERAL(34, 526, 19), // "ProcessModel::Units"
QT_MOC_LITERAL(35, 546, 4), // "unit"
QT_MOC_LITERAL(36, 551, 12), // "rowsInserted"
QT_MOC_LITERAL(37, 564, 6), // "parent"
QT_MOC_LITERAL(38, 571, 5), // "start"
QT_MOC_LITERAL(39, 577, 3), // "end"
QT_MOC_LITERAL(40, 581, 17), // "expandAllChildren"
QT_MOC_LITERAL(41, 599, 10), // "expandInit"
QT_MOC_LITERAL(42, 610, 21), // "showColumnContextMenu"
QT_MOC_LITERAL(43, 632, 5), // "point"
QT_MOC_LITERAL(44, 638, 22), // "showProcessContextMenu"
QT_MOC_LITERAL(45, 661, 5), // "index"
QT_MOC_LITERAL(46, 667, 11), // "setStateInt"
QT_MOC_LITERAL(47, 679, 17), // "filterTextChanged"
QT_MOC_LITERAL(48, 697, 7), // "newText"
QT_MOC_LITERAL(49, 705, 15), // "actionTriggered"
QT_MOC_LITERAL(50, 721, 6), // "object"
QT_MOC_LITERAL(51, 728, 16), // "showTotalsInTree"
QT_MOC_LITERAL(52, 745, 19), // "updateIntervalMSecs"
QT_MOC_LITERAL(53, 765, 5), // "units"
QT_MOC_LITERAL(54, 771, 17), // "killButtonVisible"
QT_MOC_LITERAL(55, 789, 16) // "scriptingEnabled"

    },
    "KSysGuardProcessList\0updated\0\0"
    "processListChanged\0selectionChanged\0"
    "killSelectedProcesses\0"
    "sendSignalToSelectedProcesses\0sig\0"
    "confirm\0killProcesses\0QList<long long>\0"
    "pids\0reniceSelectedProcesses\0"
    "changeCpuScheduler\0KSysGuard::Process::Scheduler\0"
    "newCpuSched\0newCpuSchedPriority\0"
    "changeIoScheduler\0KSysGuard::Process::IoPriorityClass\0"
    "newIoSched\0newIoSchedPriority\0"
    "reniceProcesses\0niceValue\0updateList\0"
    "setState\0ProcessFilter::State\0state\0"
    "setUpdateIntervalMSecs\0intervalMSecs\0"
    "setShowTotals\0showTotals\0"
    "selectAndJumpToProcess\0pid\0setUnits\0"
    "ProcessModel::Units\0unit\0rowsInserted\0"
    "parent\0start\0end\0expandAllChildren\0"
    "expandInit\0showColumnContextMenu\0point\0"
    "showProcessContextMenu\0index\0setStateInt\0"
    "filterTextChanged\0newText\0actionTriggered\0"
    "object\0showTotalsInTree\0updateIntervalMSecs\0"
    "units\0killButtonVisible\0scriptingEnabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KSysGuardProcessList[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       6,  218, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  139,    2, 0x06 /* Public */,
       3,    0,  140,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,  141,    2, 0x0a /* Public */,
       5,    0,  142,    2, 0x0a /* Public */,
       6,    2,  143,    2, 0x0a /* Public */,
       9,    2,  148,    2, 0x0a /* Public */,
      12,    0,  153,    2, 0x0a /* Public */,
      13,    3,  154,    2, 0x0a /* Public */,
      17,    3,  161,    2, 0x0a /* Public */,
      21,    2,  168,    2, 0x0a /* Public */,
      23,    0,  173,    2, 0x0a /* Public */,
      24,    1,  174,    2, 0x0a /* Public */,
      27,    1,  177,    2, 0x0a /* Public */,
      29,    1,  180,    2, 0x0a /* Public */,
      31,    1,  183,    2, 0x0a /* Public */,
      33,    1,  186,    2, 0x0a /* Public */,
      36,    3,  189,    2, 0x0a /* Public */,
      40,    1,  196,    2, 0x08 /* Private */,
      41,    0,  199,    2, 0x08 /* Private */,
      42,    1,  200,    2, 0x08 /* Private */,
      44,    1,  203,    2, 0x08 /* Private */,
      44,    1,  206,    2, 0x08 /* Private */,
      46,    1,  209,    2, 0x08 /* Private */,
      47,    1,  212,    2, 0x08 /* Private */,
      49,    1,  215,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    7,    8,
    QMetaType::Bool, 0x80000000 | 10, QMetaType::Int,   11,    7,
    QMetaType::Void,
    QMetaType::Bool, 0x80000000 | 10, 0x80000000 | 14, QMetaType::Int,   11,   15,   16,
    QMetaType::Bool, 0x80000000 | 10, 0x80000000 | 18, QMetaType::Int,   11,   19,   20,
    QMetaType::Bool, 0x80000000 | 10, QMetaType::Int,   11,   22,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 25,   26,
    QMetaType::Void, QMetaType::Int,   28,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Int,   32,
    QMetaType::Void, 0x80000000 | 34,   35,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   37,   38,   39,
    QMetaType::Void, QMetaType::QModelIndex,   37,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   43,
    QMetaType::Void, QMetaType::QModelIndex,   45,
    QMetaType::Void, QMetaType::QPoint,   43,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void, QMetaType::QString,   48,
    QMetaType::Void, QMetaType::QObjectStar,   50,

 // properties: name, type, flags
      51, QMetaType::Bool, 0x00095003,
      26, 0x80000000 | 25, 0x0009510b,
      52, QMetaType::Int, 0x00095103,
      53, 0x80000000 | 34, 0x0009510b,
      54, QMetaType::Bool, 0x00095103,
      55, QMetaType::Bool, 0x00095103,

 // enums: name, flags, count, data

 // enum data: key, value

       0        // eod
};

void KSysGuardProcessList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KSysGuardProcessList *_t = static_cast<KSysGuardProcessList *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updated(); break;
        case 1: _t->processListChanged(); break;
        case 2: _t->selectionChanged(); break;
        case 3: _t->killSelectedProcesses(); break;
        case 4: _t->sendSignalToSelectedProcesses((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: { bool _r = _t->killProcesses((*reinterpret_cast< const QList<long long>(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->reniceSelectedProcesses(); break;
        case 7: { bool _r = _t->changeCpuScheduler((*reinterpret_cast< const QList<long long>(*)>(_a[1])),(*reinterpret_cast< KSysGuard::Process::Scheduler(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->changeIoScheduler((*reinterpret_cast< const QList<long long>(*)>(_a[1])),(*reinterpret_cast< KSysGuard::Process::IoPriorityClass(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->reniceProcesses((*reinterpret_cast< const QList<long long>(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->updateList(); break;
        case 11: _t->setState((*reinterpret_cast< ProcessFilter::State(*)>(_a[1]))); break;
        case 12: _t->setUpdateIntervalMSecs((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->setShowTotals((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->selectAndJumpToProcess((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->setUnits((*reinterpret_cast< ProcessModel::Units(*)>(_a[1]))); break;
        case 16: _t->rowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 17: _t->expandAllChildren((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 18: _t->expandInit(); break;
        case 19: _t->showColumnContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 20: _t->showProcessContextMenu((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 21: _t->showProcessContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 22: _t->setStateInt((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->filterTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 24: _t->actionTriggered((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<long long> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<long long> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<long long> >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<long long> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KSysGuardProcessList::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KSysGuardProcessList::updated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KSysGuardProcessList::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KSysGuardProcessList::processListChanged)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KSysGuardProcessList *_t = static_cast<KSysGuardProcessList *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->showTotals(); break;
        case 1: *reinterpret_cast< ProcessFilter::State*>(_v) = _t->state(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->updateIntervalMSecs(); break;
        case 3: *reinterpret_cast< ProcessModel::Units*>(_v) = _t->units(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isKillButtonVisible(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->scriptingEnabled(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KSysGuardProcessList *_t = static_cast<KSysGuardProcessList *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShowTotals(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setState(*reinterpret_cast< ProcessFilter::State*>(_v)); break;
        case 2: _t->setUpdateIntervalMSecs(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setUnits(*reinterpret_cast< ProcessModel::Units*>(_v)); break;
        case 4: _t->setKillButtonVisible(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setScriptingEnabled(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject * const qt_meta_extradata_KSysGuardProcessList[] = {
        &ProcessFilter::staticMetaObject,
    &ProcessModel::staticMetaObject,
    nullptr
};

const QMetaObject KSysGuardProcessList::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KSysGuardProcessList.data,
      qt_meta_data_KSysGuardProcessList,  qt_static_metacall, qt_meta_extradata_KSysGuardProcessList, nullptr}
};


const QMetaObject *KSysGuardProcessList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSysGuardProcessList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KSysGuardProcessList.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KSysGuardProcessList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KSysGuardProcessList::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSysGuardProcessList::processListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
