#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'ProcessWidgetUI.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROCESSWIDGETUI_H
#define UI_PROCESSWIDGETUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ProcessWidget
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QPushButton *btnKillProcess;
    QLineEdit *txtFilter;
    QComboBox *cmbFilter;
    QTreeView *treeView;

    void setupUi(QWidget *ProcessWidget)
    {
        if (ProcessWidget->objectName().isEmpty())
            ProcessWidget->setObjectName(QStringLiteral("ProcessWidget"));
        ProcessWidget->resize(490, 472);
        vboxLayout = new QVBoxLayout(ProcessWidget);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        btnKillProcess = new QPushButton(ProcessWidget);
        btnKillProcess->setObjectName(QStringLiteral("btnKillProcess"));
        btnKillProcess->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(btnKillProcess->sizePolicy().hasHeightForWidth());
        btnKillProcess->setSizePolicy(sizePolicy);
        btnKillProcess->setAutoDefault(false);
        btnKillProcess->setFlat(false);

        hboxLayout->addWidget(btnKillProcess);

        txtFilter = new QLineEdit(ProcessWidget);
        txtFilter->setObjectName(QStringLiteral("txtFilter"));
        txtFilter->setProperty("clearButtonEnabled", QVariant(true));

        hboxLayout->addWidget(txtFilter);

        cmbFilter = new QComboBox(ProcessWidget);
        cmbFilter->setObjectName(QStringLiteral("cmbFilter"));
        sizePolicy.setHeightForWidth(cmbFilter->sizePolicy().hasHeightForWidth());
        cmbFilter->setSizePolicy(sizePolicy);
        cmbFilter->setMaxCount(10);
        cmbFilter->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);

        hboxLayout->addWidget(cmbFilter);


        vboxLayout->addLayout(hboxLayout);

        treeView = new QTreeView(ProcessWidget);
        treeView->setObjectName(QStringLiteral("treeView"));
        treeView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        treeView->setAlternatingRowColors(true);
        treeView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        treeView->setSelectionBehavior(QAbstractItemView::SelectRows);
        treeView->setRootIsDecorated(false);
        treeView->setUniformRowHeights(true);
        treeView->setItemsExpandable(true);
        treeView->setSortingEnabled(true);
        treeView->setAnimated(false);
        treeView->setAllColumnsShowFocus(true);

        vboxLayout->addWidget(treeView);


        retranslateUi(ProcessWidget);

        btnKillProcess->setDefault(false);


        QMetaObject::connectSlotsByName(ProcessWidget);
    } // setupUi

    void retranslateUi(QWidget *ProcessWidget)
    {
#ifndef UI_QT_NO_TOOLTIP
        btnKillProcess->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        btnKillProcess->setWhatsThis(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:8pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Attempt to kill the currently selected process by sending it the SIGTERM signal.</p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic;\">Technical information: </span><br />The SIGTERM signal is sent to the given process. If there are insufficient privileges to do so, by default a password is requested.<br />By running the program <span style=\" font-family:'Courier New,courier';\">polkit-kde-authorization</span> you can give certain (or all) users pe"
                        "rmission to kill any process, without requiring a password. </p></body></html>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        btnKillProcess->setText(tr2i18n("&End Process...", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        txtFilter->setWhatsThis(tr2i18n("Filter which processes are shown by the text given here.  The text can be a partial string match of the Name, Command or Window Title of the process.  It can also be a Username or a Process ID number.<p>\n"
"For example:\n"
"\n"
"<table>\n"
"<tr><th>ksys</th><td>Show processes containing \"<b>ksys</b>\" in the name, for example the processes \"<i>ksysguard</i>\" and \"<i>ksysguardd</i>\".<td></tr>\n"
"<tr><th>root</th><td>Show processes owned by <b>root</b>.  For example <i>init</i></td></tr>\n"
"<tr><th>1234</th><td>Show the processes with the PID or Parent PID of <b>1234</b>.</td></th></tr>\n"
"</table>\n"
"", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        txtFilter->setPlaceholderText(tr2i18n("Quick search", Q_NULLPTR));
        cmbFilter->clear();
        cmbFilter->insertItems(0, QStringList()
         << tr2i18n("All Processes", Q_NULLPTR)
         << tr2i18n("All Processes, Tree", Q_NULLPTR)
         << tr2i18n("System Processes", Q_NULLPTR)
         << tr2i18n("User Processes", Q_NULLPTR)
         << tr2i18n("Own Processes", Q_NULLPTR)
         << tr2i18n("Programs Only", Q_NULLPTR)
        );
#ifndef UI_QT_NO_WHATSTHIS
        cmbFilter->setWhatsThis(tr2i18n("<qt>Change which processes are shown, and how they are shown.  The processes can be further filtered by using the Quick Search text filter.<p>\n"
"<table>\n"
"<tr><td>All Processes</td><td>Show all the processes on the system.</td></tr>\n"
"<tr><td>All Processes, tree</td><td>Show all the processes on the system, in a hierarchical manner using the parent PID information.</td></tr>\n"
"<tr><td>System Processes</td><td>Show processes running as root and as a user who cannot login.</td></tr>\n"
"<tr><td>User Processes</td><td>Show processes running as a non-root user who can login.</td></tr>\n"
"<tr><td>Own Processes</td><td>Show processes owned by the same user that this process is owned by.</td></tr>\n"
"<tr><td>Programs Only</td><td>Show processes which are running as a user who can login and are either attached to a TTY or have at least one X11 Window.</td></tr>\n"
"</table>\n"
"<p>\n"
"<i>Technical Information:</i><br>\n"
"Processes with multiple threads are just shown as a single process, and not treated an"
                        "y differently.<br>\n"
"Kernel threads are shown as normal processes, but are actually running inside the kernel and are not real processes.  As such, many of the fields (such as Username) do not apply.\n"
"", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        Q_UNUSED(ProcessWidget);
    } // retranslateUi

};

namespace Ui {
    class ProcessWidget: public Ui_ProcessWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROCESSWIDGETUI_H

