/****************************************************************************
** Meta object code from reading C++ file 'SensorManager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libksysguard-5.8.9/ksgrd/SensorManager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SensorManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KSGRD__SensorManager_t {
    QByteArrayData data[11];
    char stringdata0[136];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KSGRD__SensorManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KSGRD__SensorManager_t qt_meta_stringdata_KSGRD__SensorManager = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KSGRD::SensorManager"
QT_MOC_LITERAL(1, 21, 6), // "update"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 9), // "hostAdded"
QT_MOC_LITERAL(4, 39, 19), // "KSGRD::SensorAgent*"
QT_MOC_LITERAL(5, 59, 11), // "sensorAgent"
QT_MOC_LITERAL(6, 71, 8), // "hostName"
QT_MOC_LITERAL(7, 80, 18), // "hostConnectionLost"
QT_MOC_LITERAL(8, 99, 11), // "reconfigure"
QT_MOC_LITERAL(9, 111, 18), // "const SensorAgent*"
QT_MOC_LITERAL(10, 130, 5) // "agent"

    },
    "KSGRD::SensorManager\0update\0\0hostAdded\0"
    "KSGRD::SensorAgent*\0sensorAgent\0"
    "hostName\0hostConnectionLost\0reconfigure\0"
    "const SensorAgent*\0agent"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KSGRD__SensorManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,
       3,    2,   35,    2, 0x06 /* Public */,
       7,    1,   40,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   43,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QString,    5,    6,
    QMetaType::Void, QMetaType::QString,    6,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 9,   10,

       0        // eod
};

void KSGRD::SensorManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SensorManager *_t = static_cast<SensorManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->update(); break;
        case 1: _t->hostAdded((*reinterpret_cast< KSGRD::SensorAgent*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->hostConnectionLost((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->reconfigure((*reinterpret_cast< const SensorAgent*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KSGRD::SensorAgent* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (SensorManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SensorManager::update)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SensorManager::*_t)(KSGRD::SensorAgent * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SensorManager::hostAdded)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (SensorManager::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SensorManager::hostConnectionLost)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KSGRD::SensorManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KSGRD__SensorManager.data,
      qt_meta_data_KSGRD__SensorManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KSGRD::SensorManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSGRD::SensorManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KSGRD__SensorManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSGRD::SensorManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KSGRD::SensorManager::update()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSGRD::SensorManager::hostAdded(KSGRD::SensorAgent * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KSGRD::SensorManager::hostConnectionLost(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
