/****************************************************************************
** Meta object code from reading C++ file 'processes.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libksysguard-5.8.9/processcore/processes.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'processes.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KSysGuard__Processes_t {
    QByteArrayData data[17];
    char stringdata0[226];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KSysGuard__Processes_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KSysGuard__Processes_t qt_meta_stringdata_KSysGuard__Processes = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KSysGuard::Processes"
QT_MOC_LITERAL(1, 21, 14), // "processChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 19), // "KSysGuard::Process*"
QT_MOC_LITERAL(4, 57, 7), // "process"
QT_MOC_LITERAL(5, 65, 12), // "onlyTotalCpu"
QT_MOC_LITERAL(6, 78, 15), // "beginAddProcess"
QT_MOC_LITERAL(7, 94, 13), // "endAddProcess"
QT_MOC_LITERAL(8, 108, 18), // "beginRemoveProcess"
QT_MOC_LITERAL(9, 127, 16), // "endRemoveProcess"
QT_MOC_LITERAL(10, 144, 16), // "beginMoveProcess"
QT_MOC_LITERAL(11, 161, 10), // "new_parent"
QT_MOC_LITERAL(12, 172, 14), // "endMoveProcess"
QT_MOC_LITERAL(13, 187, 10), // "runCommand"
QT_MOC_LITERAL(14, 198, 7), // "command"
QT_MOC_LITERAL(15, 206, 2), // "id"
QT_MOC_LITERAL(16, 209, 16) // "processesUpdated"

    },
    "KSysGuard::Processes\0processChanged\0"
    "\0KSysGuard::Process*\0process\0onlyTotalCpu\0"
    "beginAddProcess\0endAddProcess\0"
    "beginRemoveProcess\0endRemoveProcess\0"
    "beginMoveProcess\0new_parent\0endMoveProcess\0"
    "runCommand\0command\0id\0processesUpdated"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KSysGuard__Processes[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   59,    2, 0x06 /* Public */,
       6,    1,   64,    2, 0x06 /* Public */,
       7,    0,   67,    2, 0x06 /* Public */,
       8,    1,   68,    2, 0x06 /* Public */,
       9,    0,   71,    2, 0x06 /* Public */,
      10,    2,   72,    2, 0x06 /* Public */,
      12,    0,   77,    2, 0x06 /* Public */,
      13,    2,   78,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,   83,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    4,    5,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   14,   15,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KSysGuard::Processes::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Processes *_t = static_cast<Processes *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->processChanged((*reinterpret_cast< KSysGuard::Process*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->beginAddProcess((*reinterpret_cast< KSysGuard::Process*(*)>(_a[1]))); break;
        case 2: _t->endAddProcess(); break;
        case 3: _t->beginRemoveProcess((*reinterpret_cast< KSysGuard::Process*(*)>(_a[1]))); break;
        case 4: _t->endRemoveProcess(); break;
        case 5: _t->beginMoveProcess((*reinterpret_cast< KSysGuard::Process*(*)>(_a[1])),(*reinterpret_cast< KSysGuard::Process*(*)>(_a[2]))); break;
        case 6: _t->endMoveProcess(); break;
        case 7: _t->runCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->processesUpdated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Processes::*_t)(KSysGuard::Process * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Processes::processChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Processes::*_t)(KSysGuard::Process * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Processes::beginAddProcess)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Processes::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Processes::endAddProcess)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Processes::*_t)(KSysGuard::Process * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Processes::beginRemoveProcess)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Processes::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Processes::endRemoveProcess)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Processes::*_t)(KSysGuard::Process * , KSysGuard::Process * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Processes::beginMoveProcess)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Processes::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Processes::endMoveProcess)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Processes::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Processes::runCommand)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject KSysGuard::Processes::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KSysGuard__Processes.data,
      qt_meta_data_KSysGuard__Processes,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KSysGuard::Processes::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSysGuard::Processes::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KSysGuard__Processes.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSysGuard::Processes::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KSysGuard::Processes::processChanged(KSysGuard::Process * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KSysGuard::Processes::beginAddProcess(KSysGuard::Process * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KSysGuard::Processes::endAddProcess()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSysGuard::Processes::beginRemoveProcess(KSysGuard::Process * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KSysGuard::Processes::endRemoveProcess()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KSysGuard::Processes::beginMoveProcess(KSysGuard::Process * _t1, KSysGuard::Process * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KSysGuard::Processes::endMoveProcess()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KSysGuard::Processes::runCommand(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
