/****************************************************************************
** Meta object code from reading C++ file 'ProcessModel_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libksysguard-5.8.9/processui/ProcessModel_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ProcessModel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ProcessModelPrivate_t {
    QByteArrayData data[20];
    char stringdata0[238];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ProcessModelPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ProcessModelPrivate_t qt_meta_stringdata_ProcessModelPrivate = {
    {
QT_MOC_LITERAL(0, 0, 19), // "ProcessModelPrivate"
QT_MOC_LITERAL(1, 20, 13), // "windowChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 3), // "WId"
QT_MOC_LITERAL(4, 39, 3), // "wid"
QT_MOC_LITERAL(5, 43, 10), // "properties"
QT_MOC_LITERAL(6, 54, 11), // "windowAdded"
QT_MOC_LITERAL(7, 66, 13), // "windowRemoved"
QT_MOC_LITERAL(8, 80, 14), // "processChanged"
QT_MOC_LITERAL(9, 95, 19), // "KSysGuard::Process*"
QT_MOC_LITERAL(10, 115, 7), // "process"
QT_MOC_LITERAL(11, 123, 12), // "onlyCpuOrMem"
QT_MOC_LITERAL(12, 136, 14), // "beginInsertRow"
QT_MOC_LITERAL(13, 151, 6), // "parent"
QT_MOC_LITERAL(14, 158, 12), // "endInsertRow"
QT_MOC_LITERAL(15, 171, 14), // "beginRemoveRow"
QT_MOC_LITERAL(16, 186, 12), // "endRemoveRow"
QT_MOC_LITERAL(17, 199, 16), // "beginMoveProcess"
QT_MOC_LITERAL(18, 216, 10), // "new_parent"
QT_MOC_LITERAL(19, 227, 10) // "endMoveRow"

    },
    "ProcessModelPrivate\0windowChanged\0\0"
    "WId\0wid\0properties\0windowAdded\0"
    "windowRemoved\0processChanged\0"
    "KSysGuard::Process*\0process\0onlyCpuOrMem\0"
    "beginInsertRow\0parent\0endInsertRow\0"
    "beginRemoveRow\0endRemoveRow\0"
    "beginMoveProcess\0new_parent\0endMoveRow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ProcessModelPrivate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   64,    2, 0x0a /* Public */,
       6,    1,   69,    2, 0x0a /* Public */,
       7,    1,   72,    2, 0x0a /* Public */,
       8,    2,   75,    2, 0x0a /* Public */,
      12,    1,   80,    2, 0x0a /* Public */,
      14,    0,   83,    2, 0x0a /* Public */,
      15,    1,   84,    2, 0x0a /* Public */,
      16,    0,   87,    2, 0x0a /* Public */,
      17,    2,   88,    2, 0x0a /* Public */,
      19,    0,   93,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::UInt,    4,    5,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 9, QMetaType::Bool,   10,   11,
    QMetaType::Void, 0x80000000 | 9,   13,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 9,   10,   18,
    QMetaType::Void,

       0        // eod
};

void ProcessModelPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ProcessModelPrivate *_t = static_cast<ProcessModelPrivate *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->windowChanged((*reinterpret_cast< WId(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 1: _t->windowAdded((*reinterpret_cast< WId(*)>(_a[1]))); break;
        case 2: _t->windowRemoved((*reinterpret_cast< WId(*)>(_a[1]))); break;
        case 3: _t->processChanged((*reinterpret_cast< KSysGuard::Process*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 4: _t->beginInsertRow((*reinterpret_cast< KSysGuard::Process*(*)>(_a[1]))); break;
        case 5: _t->endInsertRow(); break;
        case 6: _t->beginRemoveRow((*reinterpret_cast< KSysGuard::Process*(*)>(_a[1]))); break;
        case 7: _t->endRemoveRow(); break;
        case 8: _t->beginMoveProcess((*reinterpret_cast< KSysGuard::Process*(*)>(_a[1])),(*reinterpret_cast< KSysGuard::Process*(*)>(_a[2]))); break;
        case 9: _t->endMoveRow(); break;
        default: ;
        }
    }
}

const QMetaObject ProcessModelPrivate::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ProcessModelPrivate.data,
      qt_meta_data_ProcessModelPrivate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ProcessModelPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProcessModelPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ProcessModelPrivate.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ProcessModelPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
