#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'ReniceDlgUi.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RENICEDLGUI_H
#define UI_RENICEDLGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ReniceDlgUi
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *lblMessage1;
    QListWidget *listWidget;
    QGridLayout *gridLayout;
    QLabel *imgCPU;
    QVBoxLayout *vboxLayout1;
    QSpacerItem *verticalSpacer;
    QLabel *label;
    QSpacerItem *verticalSpacer_3;
    QRadioButton *radioNormal;
    QRadioButton *radioBatch;
    QRadioButton *radioRR;
    QRadioButton *radioFIFO;
    QSpacerItem *spacerItem;
    QLabel *imgIO;
    QVBoxLayout *vboxLayout2;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_3;
    QSpacerItem *verticalSpacer_4;
    QRadioButton *radioIONormal;
    QRadioButton *radioIdle;
    QRadioButton *radioBestEffort;
    QRadioButton *radioRealTime;
    QGridLayout *gridLayout1;
    QSlider *sliderCPU;
    QLabel *lblCpuLow;
    QLabel *lblCpuHigh;
    QSpacerItem *spacerItem1;
    QGridLayout *gridLayout2;
    QSlider *sliderIO;
    QLabel *lblIOLow;
    QLabel *lblIOHigh;

    void setupUi(QWidget *ReniceDlgUi)
    {
        if (ReniceDlgUi->objectName().isEmpty())
            ReniceDlgUi->setObjectName(QStringLiteral("ReniceDlgUi"));
        ReniceDlgUi->resize(652, 397);
        vboxLayout = new QVBoxLayout(ReniceDlgUi);
        vboxLayout->setSpacing(0);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        lblMessage1 = new QLabel(ReniceDlgUi);
        lblMessage1->setObjectName(QStringLiteral("lblMessage1"));
        lblMessage1->setAlignment(Qt::AlignVCenter);
        lblMessage1->setWordWrap(true);

        vboxLayout->addWidget(lblMessage1);

        listWidget = new QListWidget(ReniceDlgUi);
        listWidget->setObjectName(QStringLiteral("listWidget"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(listWidget->sizePolicy().hasHeightForWidth());
        listWidget->setSizePolicy(sizePolicy);
        listWidget->setContextMenuPolicy(Qt::NoContextMenu);
        listWidget->setSelectionMode(QAbstractItemView::NoSelection);
        listWidget->setUniformItemSizes(true);

        vboxLayout->addWidget(listWidget);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        imgCPU = new QLabel(ReniceDlgUi);
        imgCPU->setObjectName(QStringLiteral("imgCPU"));
        imgCPU->setMinimumSize(QSize(128, 128));
        imgCPU->setMaximumSize(QSize(128, 128));
        imgCPU->setTextFormat(Qt::AutoText);

        gridLayout->addWidget(imgCPU, 0, 0, 1, 1);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(verticalSpacer);

        label = new QLabel(ReniceDlgUi);
        label->setObjectName(QStringLiteral("label"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label->setFont(font);
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        vboxLayout1->addWidget(label);

        verticalSpacer_3 = new QSpacerItem(0, 8, QSizePolicy::Minimum, QSizePolicy::Preferred);

        vboxLayout1->addItem(verticalSpacer_3);

        radioNormal = new QRadioButton(ReniceDlgUi);
        radioNormal->setObjectName(QStringLiteral("radioNormal"));

        vboxLayout1->addWidget(radioNormal);

        radioBatch = new QRadioButton(ReniceDlgUi);
        radioBatch->setObjectName(QStringLiteral("radioBatch"));

        vboxLayout1->addWidget(radioBatch);

        radioRR = new QRadioButton(ReniceDlgUi);
        radioRR->setObjectName(QStringLiteral("radioRR"));

        vboxLayout1->addWidget(radioRR);

        radioFIFO = new QRadioButton(ReniceDlgUi);
        radioFIFO->setObjectName(QStringLiteral("radioFIFO"));

        vboxLayout1->addWidget(radioFIFO);


        gridLayout->addLayout(vboxLayout1, 0, 1, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 0, 2, 1, 1);

        imgIO = new QLabel(ReniceDlgUi);
        imgIO->setObjectName(QStringLiteral("imgIO"));
        imgIO->setMinimumSize(QSize(128, 128));
        imgIO->setMaximumSize(QSize(128, 128));

        gridLayout->addWidget(imgIO, 0, 3, 1, 1);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName(QStringLiteral("vboxLayout2"));
        verticalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout2->addItem(verticalSpacer_2);

        label_3 = new QLabel(ReniceDlgUi);
        label_3->setObjectName(QStringLiteral("label_3"));
        label_3->setFont(font);
        label_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        vboxLayout2->addWidget(label_3);

        verticalSpacer_4 = new QSpacerItem(0, 8, QSizePolicy::Minimum, QSizePolicy::Preferred);

        vboxLayout2->addItem(verticalSpacer_4);

        radioIONormal = new QRadioButton(ReniceDlgUi);
        radioIONormal->setObjectName(QStringLiteral("radioIONormal"));

        vboxLayout2->addWidget(radioIONormal);

        radioIdle = new QRadioButton(ReniceDlgUi);
        radioIdle->setObjectName(QStringLiteral("radioIdle"));

        vboxLayout2->addWidget(radioIdle);

        radioBestEffort = new QRadioButton(ReniceDlgUi);
        radioBestEffort->setObjectName(QStringLiteral("radioBestEffort"));

        vboxLayout2->addWidget(radioBestEffort);

        radioRealTime = new QRadioButton(ReniceDlgUi);
        radioRealTime->setObjectName(QStringLiteral("radioRealTime"));

        vboxLayout2->addWidget(radioRealTime);


        gridLayout->addLayout(vboxLayout2, 0, 4, 1, 1);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        sliderCPU = new QSlider(ReniceDlgUi);
        sliderCPU->setObjectName(QStringLiteral("sliderCPU"));
        sliderCPU->setMinimum(-19);
        sliderCPU->setMaximum(20);
        sliderCPU->setValue(0);
        sliderCPU->setOrientation(Qt::Horizontal);
        sliderCPU->setInvertedAppearance(true);
        sliderCPU->setTickPosition(QSlider::TicksBelow);
        sliderCPU->setTickInterval(5);

        gridLayout1->addWidget(sliderCPU, 0, 0, 1, 2);

        lblCpuLow = new QLabel(ReniceDlgUi);
        lblCpuLow->setObjectName(QStringLiteral("lblCpuLow"));

        gridLayout1->addWidget(lblCpuLow, 1, 0, 1, 1);

        lblCpuHigh = new QLabel(ReniceDlgUi);
        lblCpuHigh->setObjectName(QStringLiteral("lblCpuHigh"));
        lblCpuHigh->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(lblCpuHigh, 1, 1, 1, 1);


        gridLayout->addLayout(gridLayout1, 1, 0, 1, 2);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 1, 2, 1, 1);

        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        sliderIO = new QSlider(ReniceDlgUi);
        sliderIO->setObjectName(QStringLiteral("sliderIO"));
        sliderIO->setMaximum(7);
        sliderIO->setPageStep(1);
        sliderIO->setValue(3);
        sliderIO->setSliderPosition(3);
        sliderIO->setOrientation(Qt::Horizontal);
        sliderIO->setInvertedAppearance(true);
        sliderIO->setTickPosition(QSlider::TicksBelow);
        sliderIO->setTickInterval(1);

        gridLayout2->addWidget(sliderIO, 0, 0, 1, 2);

        lblIOLow = new QLabel(ReniceDlgUi);
        lblIOLow->setObjectName(QStringLiteral("lblIOLow"));

        gridLayout2->addWidget(lblIOLow, 1, 0, 1, 1);

        lblIOHigh = new QLabel(ReniceDlgUi);
        lblIOHigh->setObjectName(QStringLiteral("lblIOHigh"));
        lblIOHigh->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(lblIOHigh, 1, 1, 1, 1);


        gridLayout->addLayout(gridLayout2, 1, 3, 1, 2);


        vboxLayout->addLayout(gridLayout);


        retranslateUi(ReniceDlgUi);

        QMetaObject::connectSlotsByName(ReniceDlgUi);
    } // setupUi

    void retranslateUi(QWidget *ReniceDlgUi)
    {
        lblMessage1->setText(tr2i18n("Change scheduling priority for:", Q_NULLPTR));
        imgCPU->setText(QString());
        label->setText(tr2i18n("CPU Scheduler", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioNormal->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The standard time-sharing scheduler for processes without special requirements.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioNormal->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Normal Scheduling: Default Linux time-sharing  (Other)</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-weight:600;\">Normal<span style=\" font-weight:400;\"> is the standard Linux time-sharing scheduler that is intended for all processes that do not  require special static priority real-time mechanisms. The process to run is chosen from the list of other</span> Normal<span style=\" font-weight:400;\"> or </span>Batch<span style=\" font-weight:400;\"> processes based on a dynamic priority that is determined only inside this list. The dynami"
                        "c priority is based on the priority level given and increased for each time-quantum the process is ready to run, but denied to run by the scheduler. This ensures fair progress among all Normal processes.</span></p></body></html>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioNormal->setText(tr2i18n("Normal", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioBatch->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">For CPU-intensive non-interactive processes.  Process is mildly disfavored in scheduling decisions.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioBatch->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Batch Scheduling</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-weight:600;\"><span style=\" font-weight:400; font-style:italic;\">(Since Linux 2.6.16.)</span><span style=\" font-weight:400;\"> This policy is similar to </span>Normal<span style=\" font-weight:400;\">, except that this policy will cause the scheduler to always assume that the process is CPU-intensive.  Consequently, the scheduler will apply a small scheduling penalty so that this process is mildly disfavored in scheduling decisions. This policy is useful for workloads that"
                        " are non-interactive, but do not want to lower their nice value, and for workloads that want a deterministic scheduling policy without interactivity causing extra preemptions (between the workload's tasks).</span></p></body></html>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioBatch->setText(tr2i18n("Batch", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioRR->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Process will run whenever runnable.  Higher priority than Normal or Batch.  Has Timeslicing.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioRR->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Round Robin Scheduling</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Round Robin</span> is a simple enhancement of <span style=\" font-weight:600;\">FIFO</span>.  Everything described below for <span style=\" font-weight:600;\">FIFO</span> also applies to <span style=\" font-weight:600;\">Round Robin</span>, except that each process is only allowed to run for a maximum time quantum.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioRR->setText(tr2i18n("Round robin", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioFIFO->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Process will run whenever runnable.  Higher priority than Normal or Batch.  No timeslicing.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioFIFO->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">First In-First Out Scheduling</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">When  a  <span style=\" font-weight:600;\">FIFO</span> process  becomes  runnable,  it  will always immediately preempt any currently running <span style=\" font-weight:600;\">Normal</span> or <span style=\" font-weight:600;\">Batch</span> process.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioFIFO->setText(tr2i18n("FIFO", Q_NULLPTR));
        imgIO->setText(QString());
        label_3->setText(tr2i18n("I/O Scheduler", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioIONormal->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Process's priority is based on the CPU priority.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioIONormal->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Normal Scheduling</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">This is the same as <span style=\" font-weight:600;\">Best Effort</span> scheduling, except that the priority is calculated automatically based on the CPU priority.  Processes with a higher priority will take priority for access to the hard disk.  Programs running at the same <span style=\" font-weight:600;\">Best Effort/Normal</span> priority are served in a <span style=\" font-weight:600;\">Round Robin</span> fashion.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioIONormal->setText(tr2i18n("Normal", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioIdle->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Process can only use the hard disk when no other process has used it very recently.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioIdle->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Idle Scheduling</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">A  program running with <span style=\" font-weight:600;\">Idle</span> I/O priority will only get disk time when no other program has asked for disk I/O for a defined grace period. The impact of <span style=\" font-weight:600;\">Idle</span> I/O processes on normal system activity should be zero. Priority is not applicable to this scheduling class.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioIdle->setText(tr2i18n("Idle", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioBestEffort->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Process is given higher priority to access the hard disk than Normal.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioBestEffort->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Best Effort Scheduling</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Processes with a higher priority will take priority for access to the hard disk.  Programs running at the same <span style=\" font-weight:600;\">Best Effort/Normal</span> priority are served in a <span style=\" font-weight:600;\">Round Robin</span> fashion.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioBestEffort->setText(tr2i18n("Best effort", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        radioRealTime->setToolTip(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Process gets immediate access to the hard disk whenever needed, regardless of what else is going on.</p></body></html>", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        radioRealTime->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Real Time Scheduling</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The <span style=\" font-weight:600;\">Real Time</span> scheduling class is given first access to the disk, regardless of what else is going on in the system. Thus the <span style=\" font-weight:600;\">Real Time</span> class needs to be used with some care, as it can starve other processes. As with the <span style=\" font-weight:600;\">Best Effort</span> class, 8 priority levels are defined denoting how big a time slice a given process will receive on each scheduling window.<"
                        "/p></body></html>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        radioRealTime->setText(tr2i18n("Real time", Q_NULLPTR));
        lblCpuLow->setText(tr2i18n("Low Priority", Q_NULLPTR));
        lblCpuHigh->setText(tr2i18n("High Priority", Q_NULLPTR));
        lblIOLow->setText(tr2i18n("Low Priority", Q_NULLPTR));
        lblIOHigh->setText(tr2i18n("High Priority", Q_NULLPTR));
        Q_UNUSED(ReniceDlgUi);
    } // retranslateUi

};

namespace Ui {
    class ReniceDlgUi: public Ui_ReniceDlgUi {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RENICEDLGUI_H

