/****************************************************************************
** Meta object code from reading C++ file 'ksignalplotter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libksysguard-5.8.9/signalplotter/ksignalplotter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksignalplotter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KSignalPlotter_t {
    QByteArrayData data[21];
    char stringdata0[287];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KSignalPlotter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KSignalPlotter_t qt_meta_stringdata_KSignalPlotter = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KSignalPlotter"
QT_MOC_LITERAL(1, 15, 16), // "axisScaleChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 12), // "minimumValue"
QT_MOC_LITERAL(4, 46, 12), // "maximumValue"
QT_MOC_LITERAL(5, 59, 12), // "useAutoRange"
QT_MOC_LITERAL(6, 72, 4), // "unit"
QT_MOC_LITERAL(7, 77, 16), // "KLocalizedString"
QT_MOC_LITERAL(8, 94, 11), // "scaleDownBy"
QT_MOC_LITERAL(9, 106, 15), // "horizontalScale"
QT_MOC_LITERAL(10, 122, 19), // "showHorizontalLines"
QT_MOC_LITERAL(11, 142, 17), // "showVerticalLines"
QT_MOC_LITERAL(12, 160, 19), // "verticalLinesScroll"
QT_MOC_LITERAL(13, 180, 21), // "verticalLinesDistance"
QT_MOC_LITERAL(14, 202, 8), // "showAxis"
QT_MOC_LITERAL(15, 211, 13), // "svgBackground"
QT_MOC_LITERAL(16, 225, 9), // "thinFrame"
QT_MOC_LITERAL(17, 235, 16), // "maxAxisTextWidth"
QT_MOC_LITERAL(18, 252, 11), // "smoothGraph"
QT_MOC_LITERAL(19, 264, 10), // "stackGraph"
QT_MOC_LITERAL(20, 275, 11) // "fillOpacity"

    },
    "KSignalPlotter\0axisScaleChanged\0\0"
    "minimumValue\0maximumValue\0useAutoRange\0"
    "unit\0KLocalizedString\0scaleDownBy\0"
    "horizontalScale\0showHorizontalLines\0"
    "showVerticalLines\0verticalLinesScroll\0"
    "verticalLinesDistance\0showAxis\0"
    "svgBackground\0thinFrame\0maxAxisTextWidth\0"
    "smoothGraph\0stackGraph\0fillOpacity"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KSignalPlotter[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
      17,   20, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

 // properties: name, type, flags
       3, QMetaType::QReal, 0x00095103,
       4, QMetaType::QReal, 0x00095103,
       5, QMetaType::Bool, 0x00095103,
       6, 0x80000000 | 7, 0x0009510b,
       8, QMetaType::QReal, 0x00095103,
       9, QMetaType::UInt, 0x00095103,
      10, QMetaType::Bool, 0x00095103,
      11, QMetaType::Bool, 0x00095103,
      12, QMetaType::Bool, 0x00095103,
      13, QMetaType::UInt, 0x00095103,
      14, QMetaType::Bool, 0x00095103,
      15, QMetaType::QString, 0x00095103,
      16, QMetaType::Bool, 0x00095103,
      17, QMetaType::Int, 0x00095103,
      18, QMetaType::Bool, 0x00095103,
      19, QMetaType::Bool, 0x00095103,
      20, QMetaType::Int, 0x00095103,

       0        // eod
};

void KSignalPlotter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KSignalPlotter *_t = static_cast<KSignalPlotter *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->axisScaleChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KSignalPlotter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KSignalPlotter::axisScaleChanged)) {
                *result = 0;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KLocalizedString >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KSignalPlotter *_t = static_cast<KSignalPlotter *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->minimumValue(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->maximumValue(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->useAutoRange(); break;
        case 3: *reinterpret_cast< KLocalizedString*>(_v) = _t->unit(); break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->scaleDownBy(); break;
        case 5: *reinterpret_cast< uint*>(_v) = _t->horizontalScale(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->showHorizontalLines(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->showVerticalLines(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->verticalLinesScroll(); break;
        case 9: *reinterpret_cast< uint*>(_v) = _t->verticalLinesDistance(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->showAxis(); break;
        case 11: *reinterpret_cast< QString*>(_v) = _t->svgBackground(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->thinFrame(); break;
        case 13: *reinterpret_cast< int*>(_v) = _t->maxAxisTextWidth(); break;
        case 14: *reinterpret_cast< bool*>(_v) = _t->smoothGraph(); break;
        case 15: *reinterpret_cast< bool*>(_v) = _t->stackGraph(); break;
        case 16: *reinterpret_cast< int*>(_v) = _t->fillOpacity(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KSignalPlotter *_t = static_cast<KSignalPlotter *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMinimumValue(*reinterpret_cast< qreal*>(_v)); break;
        case 1: _t->setMaximumValue(*reinterpret_cast< qreal*>(_v)); break;
        case 2: _t->setUseAutoRange(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setUnit(*reinterpret_cast< KLocalizedString*>(_v)); break;
        case 4: _t->setScaleDownBy(*reinterpret_cast< qreal*>(_v)); break;
        case 5: _t->setHorizontalScale(*reinterpret_cast< uint*>(_v)); break;
        case 6: _t->setShowHorizontalLines(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setShowVerticalLines(*reinterpret_cast< bool*>(_v)); break;
        case 8: _t->setVerticalLinesScroll(*reinterpret_cast< bool*>(_v)); break;
        case 9: _t->setVerticalLinesDistance(*reinterpret_cast< uint*>(_v)); break;
        case 10: _t->setShowAxis(*reinterpret_cast< bool*>(_v)); break;
        case 11: _t->setSvgBackground(*reinterpret_cast< QString*>(_v)); break;
        case 12: _t->setThinFrame(*reinterpret_cast< bool*>(_v)); break;
        case 13: _t->setMaxAxisTextWidth(*reinterpret_cast< int*>(_v)); break;
        case 14: _t->setSmoothGraph(*reinterpret_cast< bool*>(_v)); break;
        case 15: _t->setStackGraph(*reinterpret_cast< bool*>(_v)); break;
        case 16: _t->setFillOpacity(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KSignalPlotter::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KSignalPlotter.data,
      qt_meta_data_KSignalPlotter,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KSignalPlotter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSignalPlotter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KSignalPlotter.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KSignalPlotter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 17;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KSignalPlotter::axisScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
