/****************************************************************************
** Meta object code from reading C++ file 'SensorShellAgent.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libksysguard-5.8.9/ksgrd/SensorShellAgent.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SensorShellAgent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KSGRD__SensorShellAgent_t {
    QByteArrayData data[11];
    char stringdata0[145];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KSGRD__SensorShellAgent_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KSGRD__SensorShellAgent_t qt_meta_stringdata_KSGRD__SensorShellAgent = {
    {
QT_MOC_LITERAL(0, 0, 23), // "KSGRD::SensorShellAgent"
QT_MOC_LITERAL(1, 24, 7), // "msgRcvd"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 10), // "errMsgRcvd"
QT_MOC_LITERAL(4, 44, 12), // "daemonExited"
QT_MOC_LITERAL(5, 57, 8), // "exitCode"
QT_MOC_LITERAL(6, 66, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(7, 87, 10), // "exitStatus"
QT_MOC_LITERAL(8, 98, 11), // "daemonError"
QT_MOC_LITERAL(9, 110, 22), // "QProcess::ProcessError"
QT_MOC_LITERAL(10, 133, 11) // "errorStatus"

    },
    "KSGRD::SensorShellAgent\0msgRcvd\0\0"
    "errMsgRcvd\0daemonExited\0exitCode\0"
    "QProcess::ExitStatus\0exitStatus\0"
    "daemonError\0QProcess::ProcessError\0"
    "errorStatus"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KSGRD__SensorShellAgent[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x08 /* Private */,
       3,    0,   35,    2, 0x08 /* Private */,
       4,    2,   36,    2, 0x08 /* Private */,
       8,    1,   41,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 6,    5,    7,
    QMetaType::Void, 0x80000000 | 9,   10,

       0        // eod
};

void KSGRD::SensorShellAgent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SensorShellAgent *_t = static_cast<SensorShellAgent *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->msgRcvd(); break;
        case 1: _t->errMsgRcvd(); break;
        case 2: _t->daemonExited((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 3: _t->daemonError((*reinterpret_cast< QProcess::ProcessError(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KSGRD::SensorShellAgent::staticMetaObject = {
    { &SensorAgent::staticMetaObject, qt_meta_stringdata_KSGRD__SensorShellAgent.data,
      qt_meta_data_KSGRD__SensorShellAgent,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KSGRD::SensorShellAgent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSGRD::SensorShellAgent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KSGRD__SensorShellAgent.stringdata0))
        return static_cast<void*>(this);
    return SensorAgent::qt_metacast(_clname);
}

int KSGRD::SensorShellAgent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SensorAgent::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
